=======
Credits
=======

Development Lead
----------------
* `Cesar Rodriguez <https://www.cloudsecuritymusings.com>`_ - cesar@cloudsecuritymusings.com

Contributors
------------

* `sbalbach <https://github.com/sbalbach>`_
* `Zach Zeid <https://github.com/zachzeid>`_
* `Logan Rakai <https://github.com/lrakai>`_
* `Guy Kisel <https://github.com/guykisel>`_
